# wanha - your pesky URL-guardian for IRC
# Copyright (C) 2006-2007 Tommi Saviranta  <wnd@iki.fi>
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA


package Wanha::HTML;

use strict;
use warnings FATAL => 'all';
use diagnostics;

use Wanha::Lang;
use Wanha::Config;


=item print_header
Print HTML header

0: subtitle
@: extra stuff to head
=cut
sub print_header($@) {
	my $sub = shift;
	my $title;
	if (defined($sub)) {
		$title = &Wanha::Lang::get("title-short") . " - " . $sub;
	} else {
		$title = &Wanha::Lang::get("title-long");
	}
	my $url = $Wanha::Config::base_url;
	print <<EOF;
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN"
	"http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">

<html xml:lang="en" xmlns="http://www.w3.org/1999/xhtml">

<head>
	<title>$title</title>
	<link rel="stylesheet" type="text/css" media="screen"
			href="style.css" title="default" />
	<link rel="icon" href="$url/favicon.ico" type="image/x-icon" />
	<link rel="shortcut icon" href="$url/favicon.ico" type="image/x-icon" />
EOF
	foreach (@_) {
		print "\t$_\n";
	}
	print <<EOF;
</head>

<body>
EOF
}


=item print_footer
Print HTML footer

0: time to generate the page
=cut
sub print_footer($) {
	my ($time) = @_;
	if (defined($time)) {
		$time = " " . sprintf(&Wanha::Lang::get("txt-generate"), $time);
	} else {
		$time = "";
	}
	print <<EOF;
<p id="greasemonkey">
Install
<a href="http://greasemonkey.mozdev.org/">Greasemonkey</a>
<a href="wanha_urls_in_tabs.user.js">script to open links in new tabs</a>.
</p>

<hr />
<p>
	Copyright &copy; 2006-2007
	<a href="http://iki.fi/wnd/contact.html">Tommi Saviranta</a>
	-- <a href="http://iki.fi/wnd/src/wanha">Sources</a>$time
</p>

</body>
</html>
EOF
}


=item bad_param
Act upon bad parameters

0: msg
=cut
sub bad_param($) {
	my ($msg) = @_;
	print "<h1>LOL WTF n00b I pwn</h1>\n";
	(defined($msg)) && print "<p>$msg</p>\n";
	&print_footer();
	exit(0);
}


=item esc_param
Make parameters safe

@: options
r: parameter string
=cut
sub esc_param(@) {
	my $url = "";
	my $first = 1;
	foreach (@_) {
		my $i = "$_";
		$i =~ s/#/%23/;
		$i =~ s/&/%26/;
		$i =~ s/\?/%3f/;
		if ($first == 0) {
			$url .= "&amp;";
		} else {
			$first = 0;
		}
		$url .= $i;
	}
	return $url;
}


=item truncate_url
Truncate URL nicely

0: url
1: len = 60
2: end = 10
r: url
=cut
sub truncate_url($$$) {
	my ($url, $len, $end) = @_;
	$len = 60 if (! defined($len));
	$end = 10 if (! defined($end));

	my $rl = length($url);
	($rl <= $len) && return $url;

	# Can we do it nicely and cleanly?
	my ($domain, $path) = $url =~ /([a-z]+:\/\/.*?)\/(.*)/;
	if (! defined($domain)) {
		$domain = $url;
		$path = "";
	}
	if (length($domain) < $len) {
		my @t = split(/\//, $path);
		my $count = $#t + 1;
		while ($count > 1) {
			my $newurl = $domain . "/...";
			for (my $i = $#t + 1 - $count; $i < $#t + 1; $i++) {
				$newurl .= "/" . $t[$i];
			}
			if (length($newurl) <= $len) {
				return $newurl;
			}
			$count--;
		}
	}

	# Fallback...
	return (substr($url, 0, $len - $end - 3) . "..." .
			substr($url, $rl - $end));
}


=item htmlize
Make text proper HTML

0: string
r: html
=cut
sub htmlize($) {
	my ($t) = @_;
	$t =~ s/&/\&amp;/g;
	$t =~ s/</\&lt;/g;
	$t =~ s/>/\&gt;/g;
	return $t;
}


return 1;
